<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class LogsIntegracaoSAPController extends \Teknisa\MAN\Controllers\TeknisaCrud {
    protected $logsIntegracaoSAPService;
    protected $utilService;
    protected $dataSourceName = "smtp";
    protected $parameterBagColumns = array('NRORG');
	protected $SMTPService;
    
    public function __construct(Services\LogsIntegracaoSAPService $LogsIntegracaoSAPService, Utilities\Util $utilService) {
        $this->logsIntegracaoSAPService = $LogsIntegracaoSAPService;
        $this->utilService = $utilService;
    }
    
    public function findNotificacoes (DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if (isset($conditions["DTMOVIMENTACAO"]) && isset($conditions["DTMOVIMENTACAO"]["start"]) && isset($conditions["DTMOVIMENTACAO"]["end"])) {
            $conditions["DTMOVIMENTACAO"][0] = $conditions["DTMOVIMENTACAO"]["start"];
            $conditions["DTMOVIMENTACAO"][1] = $conditions["DTMOVIMENTACAO"]["end"];
        }

        foreach ($conditions as $key => &$value) {
            if (is_array($value) && $key != "DTMOVIMENTACAO") {
                $value = implode(",", $value);
            }
        }   
        
        // build params
        $params = array(
            "CDFILIAL" => $conditions["CDFILIAL"] ?? "T",
	        "CDCAIXA" => $conditions["CDCAIXA"] ?? "T",
	        "CDLOJA" => $conditions["CDLOJA"] ?? "T",
	        "DTINICIAL" => $conditions["DTMOVIMENTACAO"][0] ?? NULL,
	        "DTFINAL" => $conditions["DTMOVIMENTACAO"][1] ?? NULL
        );
        
        $result = $this->logsIntegracaoSAPService->findNotificacoes($params);
        
        $response->addDataSet(new DataSet('notificacoesSAP', $result));
    }
    
     public function findConsultas (DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if (isset($conditions["DTMOVIMENTACAO"]["start"]) && isset($conditions["DTMOVIMENTACAO"]["end"])) {
            $conditions["DTMOVIMENTACAO"][0] = $conditions["DTMOVIMENTACAO"]["start"];
            $conditions["DTMOVIMENTACAO"][1] = $conditions["DTMOVIMENTACAO"]["end"];
        }

        foreach ($conditions as $key => &$value) {
            if (is_array($value) && $key != "DTMOVIMENTACAO") {
                $value = implode(",", $value);
            }
        }
        
        // build params
        $params = array(
            "CDFILIAL" => $conditions["CDFILIAL"] ?? "T",
	        "CDCAIXA" => $conditions["CDCAIXA"] ?? "T",
	        "CDLOJA" => $conditions["CDLOJA"] ?? "T",
	        "DTINICIAL" => $conditions["DTMOVIMENTACAO"][0],
	        "DTFINAL" => $conditions["DTMOVIMENTACAO"][1]
        );
        
        $result = $this->logsIntegracaoSAPService->findConsultas($params);
        
        $response->addDataSet(new DataSet('consultasSAP', $result));
    }
    
}